@@ -63,11 +63,11 @@ def requests_decorator(method=METHOD_GET, success_code=200, stop_code=None, fail
                     ):
                         break
                 except ConnectionError as e:
-                    raise ConnectionError(e)
+                    raise e
                 except ConnError as e:
-                    raise ConnError(e)
+                    raise e
                 except TypeError as e:
-                    raise TypeError(e)
+                    raise e
                 except Exception as e:
                     pass
             if response is None:
