@@ -49,3 +49,24 @@ class AuthMiddleware(MiddlewareMixin):
                         return True
 
         return False
+
+
+class TenantMiddleware(MiddlewareMixin):
+    def process_request(self, request):
+        path = request.path
+        results = Results()
+        tenant = None
+        if "login" not in path and path not in IGNORE_SOURCE:
+            token = request.GET.get('token')
+            if token:
+                tenant = Tenant.objects.filter(token=token).first()
+            else:
+                account = request.session.get("account", None)
+                if account:
+                    tenant = Tenant.objects.filter(account=account).first()
+            if not tenant:
+                results.describe = "The tenant does not exist!!!"
+                results.code = FORBID_CODE
+                return RESTResponse(results)
+            else:
+                setattr(request, 'tenant', tenant)
