@@ -24,6 +24,18 @@ def get_uuid():
     return suid
 
 
+def to_utc_time(_time):
+    if '+' in _time:
+        times = _time.split("+")
+        _time = times[0]
+        v = times[1]
+        f_srt = '%Y-%m-%dT%H:%M:%S.%f' if '.' in _time else '%Y-%m-%dT%H:%M:%S'
+        _time = datetime.strptime(_time, f_srt) - timedelta(hours=int(v.split(':')[0]))
+        _time = _time.strftime('%Y-%m-%dT%H:%M:%S.%f')[:-3] + "Z"
+
+    return _time
+
+
 def convert_time(_time):
     if '+' in _time:
         times = _time.split("+")
@@ -31,13 +43,13 @@ def convert_time(_time):
         v = times[1]
         f_srt = '%Y-%m-%dT%H:%M:%S.%f' if '.' in _time else '%Y-%m-%dT%H:%M:%S'
         _time = datetime.strptime(_time, f_srt) + timedelta(hours=8 - int(v.split(':')[0]))
-        _time = _time.strftime('%Y-%m-%dT%H:%M:%S.%f')[:-3] + 'Z'
-    # elif 'Z' in _time:
-    #     f_srt = '%Y-%m-%dT%H:%M:%S.%fZ' if '.' in _time else '%Y-%m-%dT%H:%M:%SZ'
-    #     _time = datetime.strptime(_time, f_srt) + timedelta(hours=8)
-    #     _time = _time.strftime('%Y-%m-%dT%H:%M:%S.%fZ')
+        _time = _time.strftime('%Y-%m-%d %H:%M:%S.%f')[:-3]
+    elif 'Z' in _time:
+        f_srt = '%Y-%m-%dT%H:%M:%S.%fZ' if '.' in _time else '%Y-%m-%dT%H:%M:%SZ'
+        _time = datetime.strptime(_time, f_srt) + timedelta(hours=8)
+        _time = _time.strftime('%Y-%m-%d %H:%M:%S.%f')[:-3]
     return _time
 
 
 if __name__ == '__main__':
-    print(convert_time('2021-10-21T03:30:04.449+02:00'))
+    print(to_utc_time('2021-10-21T03:30:04.449+02'))
